Struct interceptor::twcc::Recorder [−][src]
pub struct Recorder { /* fields omitted */ }Expand description
Recorder records incoming RTP packets and their delays and creates transport wide congestion control feedback reports as specified in https://datatracker.ietf.org/doc/html/draft-holmer-rmcat-transport-wide-cc-extensions-01
Implementations
new creates a new Recorder which uses the given sender_ssrc in the created feedback packets.
record marks a packet with media_ssrc and a transport wide sequence number sequence_number as received at arrival_time.